from recognizers_text.model import ModelResult
from recognizers_text.culture import Culture
from recognizers_number.number.number_recognizer import recognize_number, recognize_ordinal, recognize_percentage, NumberOptions
from recognizers_number_with_unit.number_with_unit.number_with_unit_recognizer import recognize_age, recognize_currency, recognize_dimension, recognize_temperature, NumberWithUnitOptions
from recognizers_date_time.date_time.date_time_recognizer import recognize_datetime, DateTimeOptions
from recognizers_sequence.sequence.sequence_recognizer import recognize_phone_number, recognize_email, recognize_url, recognize_ip_address, SequenceOptions
from recognizers_choice.choice.recognizers_choice import *



# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License.

import os
from setuptools import setup, find_packages


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


NAME = 'recognizers-text-suite'
VERSION = '1.0.2.a0'
REQUIRES = ['recognizers-text>=1.0.2.a0', 'recognizers-text-number>=1.0.2.a0', 'recognizers-text-number-with-unit>=1.0.2.a0',
            'recognizers-text-date-time>=1.0.2.a0', 'recognizers-text-sequence>=1.0.2.a0', 'recognizers-text-choice>=1.0.2.a0']

setup(
    name=NAME,
    version=VERSION,
    url='https://github.com/Microsoft/Recognizers-Text',
    author='Microsoft',
    description='recognizers-text-suite README',
    keywords=['nlp', 'nlp-entity-extraction',
              'entity-extraction', 'parser-library'],
    long_description=read('README.rst'),
    license='MIT',
    packages=find_packages(),
    install_requires=REQUIRES,
    classifiers=[
        'Programming Language :: Python :: 3.6',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Development Status :: 3 - Alpha',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
    ]
)
